==> leatherman-1.7.2.tgz: lib/cmake/leatherman/LeathermanLibraries-release.cmake <==
#----------------------------------------------------------------
# Generated CMake target import file for configuration "Release".
#----------------------------------------------------------------

# Commands may need to know the format version.
set(CMAKE_IMPORT_FILE_VERSION 1)

# Import target "leatherman_util" for configuration "Release"
set_property(TARGET leatherman_util APPEND PROPERTY IMPORTED_CONFIGURATIONS RELEASE)
set_target_properties(leatherman_util PROPERTIES
  IMPORTED_LOCATION_RELEASE "${_IMPORT_PREFIX}/lib/libleatherman_util.so.1.1"
  IMPORTED_SONAME_RELEASE "libleatherman_util.so.1.1"
  )

list(APPEND _IMPORT_CHECK_TARGETS leatherman_util )
list(APPEND _IMPORT_CHECK_FILES_FOR_leatherman_util "${_IMPORT_PREFIX}/lib/libleatherman_util.so.1.1" )

# Import target "leatherman_locale" for configuration "Release"
set_property(TARGET leatherman_locale APPEND PROPERTY IMPORTED_CONFIGURATIONS RELEASE)
set_target_properties(leatherman_locale PROPERTIES
  IMPORTED_LOCATION_RELEASE "${_IMPORT_PREFIX}/lib/libleatherman_locale.so.1.0"
  IMPORTED_SONAME_RELEASE "libleatherman_locale.so.1.0"
  )

list(APPEND _IMPORT_CHECK_TARGETS leatherman_locale )
list(APPEND _IMPORT_CHECK_FILES_FOR_leatherman_locale "${_IMPORT_PREFIX}/lib/libleatherman_locale.so.1.0" )

# Import target "leatherman_logging" for configuration "Release"
set_property(TARGET leatherman_logging APPEND PROPERTY IMPORTED_CONFIGURATIONS RELEASE)
set_target_properties(leatherman_logging PROPERTIES
  IMPORTED_LOCATION_RELEASE "${_IMPORT_PREFIX}/lib/libleatherman_logging.so.1.0"
  IMPORTED_SONAME_RELEASE "libleatherman_logging.so.1.0"
  )

list(APPEND _IMPORT_CHECK_TARGETS leatherman_logging )
list(APPEND _IMPORT_CHECK_FILES_FOR_leatherman_logging "${_IMPORT_PREFIX}/lib/libleatherman_logging.so.1.0" )

# Import target "leatherman_json_container" for configuration "Release"
set_property(TARGET leatherman_json_container APPEND PROPERTY IMPORTED_CONFIGURATIONS RELEASE)
set_target_properties(leatherman_json_container PROPERTIES
  IMPORTED_LOCATION_RELEASE "${_IMPORT_PREFIX}/lib/libleatherman_json_container.so.1.1"
  IMPORTED_SONAME_RELEASE "libleatherman_json_container.so.1.1"
  )

list(APPEND _IMPORT_CHECK_TARGETS leatherman_json_container )
list(APPEND _IMPORT_CHECK_FILES_FOR_leatherman_json_container "${_IMPORT_PREFIX}/lib/libleatherman_json_container.so.1.1" )

# Import target "leatherman_file_util" for configuration "Release"
set_property(TARGET leatherman_file_util APPEND PROPERTY IMPORTED_CONFIGURATIONS RELEASE)
set_target_properties(leatherman_file_util PROPERTIES
  IMPORTED_LOCATION_RELEASE "${_IMPORT_PREFIX}/lib/libleatherman_file_util.so.1.1"
  IMPORTED_SONAME_RELEASE "libleatherman_file_util.so.1.1"
  )

list(APPEND _IMPORT_CHECK_TARGETS leatherman_file_util )
list(APPEND _IMPORT_CHECK_FILES_FOR_leatherman_file_util "${_IMPORT_PREFIX}/lib/libleatherman_file_util.so.1.1" )

# Import target "leatherman_curl" for configuration "Release"
set_property(TARGET leatherman_curl APPEND PROPERTY IMPORTED_CONFIGURATIONS RELEASE)
set_target_properties(leatherman_curl PROPERTIES
  IMPORTED_LOCATION_RELEASE "${_IMPORT_PREFIX}/lib/libleatherman_curl.so.1.1"
  IMPORTED_SONAME_RELEASE "libleatherman_curl.so.1.1"
  )

list(APPEND _IMPORT_CHECK_TARGETS leatherman_curl )
list(APPEND _IMPORT_CHECK_FILES_FOR_leatherman_curl "${_IMPORT_PREFIX}/lib/libleatherman_curl.so.1.1" )

# Import target "leatherman_dynamic_library" for configuration "Release"
set_property(TARGET leatherman_dynamic_library APPEND PROPERTY IMPORTED_CONFIGURATIONS RELEASE)
set_target_properties(leatherman_dynamic_library PROPERTIES
  IMPORTED_LOCATION_RELEASE "${_IMPORT_PREFIX}/lib/libleatherman_dynamic_library.so.1.0"
  IMPORTED_SONAME_RELEASE "libleatherman_dynamic_library.so.1.0"
  )

list(APPEND _IMPORT_CHECK_TARGETS leatherman_dynamic_library )
list(APPEND _IMPORT_CHECK_FILES_FOR_leatherman_dynamic_library "${_IMPORT_PREFIX}/lib/libleatherman_dynamic_library.so.1.0" )

# Import target "leatherman_execution" for configuration "Release"
set_property(TARGET leatherman_execution APPEND PROPERTY IMPORTED_CONFIGURATIONS RELEASE)
set_target_properties(leatherman_execution PROPERTIES
  IMPORTED_LOCATION_RELEASE "${_IMPORT_PREFIX}/lib/libleatherman_execution.so.1.1"
  IMPORTED_SONAME_RELEASE "libleatherman_execution.so.1.1"
  )

list(APPEND _IMPORT_CHECK_TARGETS leatherman_execution )
list(APPEND _IMPORT_CHECK_FILES_FOR_leatherman_execution "${_IMPORT_PREFIX}/lib/libleatherman_execution.so.1.1" )

# Import target "leatherman_ruby" for configuration "Release"
set_property(TARGET leatherman_ruby APPEND PROPERTY IMPORTED_CONFIGURATIONS RELEASE)
set_target_properties(leatherman_ruby PROPERTIES
  IMPORTED_LOCATION_RELEASE "${_IMPORT_PREFIX}/lib/libleatherman_ruby.so.1.0"
  IMPORTED_SONAME_RELEASE "libleatherman_ruby.so.1.0"
  )

list(APPEND _IMPORT_CHECK_TARGETS leatherman_ruby )
list(APPEND _IMPORT_CHECK_FILES_FOR_leatherman_ruby "${_IMPORT_PREFIX}/lib/libleatherman_ruby.so.1.0" )

# Commands beyond this point should not need to know the version.
set(CMAKE_IMPORT_FILE_VERSION)

==> leatherman-1.12.6p0.tgz: lib/cmake/leatherman/LeathermanLibraries-release.cmake <==
#----------------------------------------------------------------
# Generated CMake target import file for configuration "Release".
#----------------------------------------------------------------

# Commands may need to know the format version.
set(CMAKE_IMPORT_FILE_VERSION 1)

# Import target "leatherman_util" for configuration "Release"
set_property(TARGET leatherman_util APPEND PROPERTY IMPORTED_CONFIGURATIONS RELEASE)
set_target_properties(leatherman_util PROPERTIES
  IMPORTED_LOCATION_RELEASE "${_IMPORT_PREFIX}/lib/libleatherman_util.so.1.1"
  IMPORTED_SONAME_RELEASE "libleatherman_util.so.1.1"
  )

list(APPEND _IMPORT_CHECK_TARGETS leatherman_util )
list(APPEND _IMPORT_CHECK_FILES_FOR_leatherman_util "${_IMPORT_PREFIX}/lib/libleatherman_util.so.1.1" )

# Import target "leatherman_locale" for configuration "Release"
set_property(TARGET leatherman_locale APPEND PROPERTY IMPORTED_CONFIGURATIONS RELEASE)
set_target_properties(leatherman_locale PROPERTIES
  IMPORTED_LINK_DEPENDENT_LIBRARIES_RELEASE "leatherman_util"
  IMPORTED_LOCATION_RELEASE "${_IMPORT_PREFIX}/lib/libleatherman_locale.so.1.0"
  IMPORTED_SONAME_RELEASE "libleatherman_locale.so.1.0"
  )

list(APPEND _IMPORT_CHECK_TARGETS leatherman_locale )
list(APPEND _IMPORT_CHECK_FILES_FOR_leatherman_locale "${_IMPORT_PREFIX}/lib/libleatherman_locale.so.1.0" )

# Import target "leatherman_logging" for configuration "Release"
set_property(TARGET leatherman_logging APPEND PROPERTY IMPORTED_CONFIGURATIONS RELEASE)
set_target_properties(leatherman_logging PROPERTIES
  IMPORTED_LINK_DEPENDENT_LIBRARIES_RELEASE "leatherman_locale"
  IMPORTED_LOCATION_RELEASE "${_IMPORT_PREFIX}/lib/libleatherman_logging.so.1.0"
  IMPORTED_SONAME_RELEASE "libleatherman_logging.so.1.0"
  )

list(APPEND _IMPORT_CHECK_TARGETS leatherman_logging )
list(APPEND _IMPORT_CHECK_FILES_FOR_leatherman_logging "${_IMPORT_PREFIX}/lib/libleatherman_logging.so.1.0" )

# Import target "leatherman_json_container" for configuration "Release"
set_property(TARGET leatherman_json_container APPEND PROPERTY IMPORTED_CONFIGURATIONS RELEASE)
set_target_properties(leatherman_json_container PROPERTIES
  IMPORTED_LINK_DEPENDENT_LIBRARIES_RELEASE "leatherman_locale"
  IMPORTED_LOCATION_RELEASE "${_IMPORT_PREFIX}/lib/libleatherman_json_container.so.1.1"
  IMPORTED_SONAME_RELEASE "libleatherman_json_container.so.1.1"
  )

list(APPEND _IMPORT_CHECK_TARGETS leatherman_json_container )
list(APPEND _IMPORT_CHECK_FILES_FOR_leatherman_json_container "${_IMPORT_PREFIX}/lib/libleatherman_json_container.so.1.1" )

# Import target "leatherman_file_util" for configuration "Release"
set_property(TARGET leatherman_file_util APPEND PROPERTY IMPORTED_CONFIGURATIONS RELEASE)
set_target_properties(leatherman_file_util PROPERTIES
  IMPORTED_LINK_DEPENDENT_LIBRARIES_RELEASE "leatherman_locale;leatherman_logging;leatherman_util"
  IMPORTED_LOCATION_RELEASE "${_IMPORT_PREFIX}/lib/libleatherman_file_util.so.1.1"
  IMPORTED_SONAME_RELEASE "libleatherman_file_util.so.1.1"
  )

list(APPEND _IMPORT_CHECK_TARGETS leatherman_file_util )
list(APPEND _IMPORT_CHECK_FILES_FOR_leatherman_file_util "${_IMPORT_PREFIX}/lib/libleatherman_file_util.so.1.1" )

# Import target "leatherman_curl" for configuration "Release"
set_property(TARGET leatherman_curl APPEND PROPERTY IMPORTED_CONFIGURATIONS RELEASE)
set_target_properties(leatherman_curl PROPERTIES
  IMPORTED_LINK_DEPENDENT_LIBRARIES_RELEASE "leatherman_locale;leatherman_logging;leatherman_util;leatherman_file_util"
  IMPORTED_LOCATION_RELEASE "${_IMPORT_PREFIX}/lib/libleatherman_curl.so.1.1"
  IMPORTED_SONAME_RELEASE "libleatherman_curl.so.1.1"
  )

list(APPEND _IMPORT_CHECK_TARGETS leatherman_curl )
list(APPEND _IMPORT_CHECK_FILES_FOR_leatherman_curl "${_IMPORT_PREFIX}/lib/libleatherman_curl.so.1.1" )

# Import target "leatherman_dynamic_library" for configuration "Release"
set_property(TARGET leatherman_dynamic_library APPEND PROPERTY IMPORTED_CONFIGURATIONS RELEASE)
set_target_properties(leatherman_dynamic_library PROPERTIES
  IMPORTED_LINK_DEPENDENT_LIBRARIES_RELEASE "leatherman_locale;leatherman_logging;leatherman_util"
  IMPORTED_LOCATION_RELEASE "${_IMPORT_PREFIX}/lib/libleatherman_dynamic_library.so.1.0"
  IMPORTED_SONAME_RELEASE "libleatherman_dynamic_library.so.1.0"
  )

list(APPEND _IMPORT_CHECK_TARGETS leatherman_dynamic_library )
list(APPEND _IMPORT_CHECK_FILES_FOR_leatherman_dynamic_library "${_IMPORT_PREFIX}/lib/libleatherman_dynamic_library.so.1.0" )

# Import target "leatherman_execution" for configuration "Release"
set_property(TARGET leatherman_execution APPEND PROPERTY IMPORTED_CONFIGURATIONS RELEASE)
set_target_properties(leatherman_execution PROPERTIES
  IMPORTED_LINK_DEPENDENT_LIBRARIES_RELEASE "leatherman_util;leatherman_locale;leatherman_logging;leatherman_file_util"
  IMPORTED_LOCATION_RELEASE "${_IMPORT_PREFIX}/lib/libleatherman_execution.so.2.0"
  IMPORTED_SONAME_RELEASE "libleatherman_execution.so.2.0"
  )

list(APPEND _IMPORT_CHECK_TARGETS leatherman_execution )
list(APPEND _IMPORT_CHECK_FILES_FOR_leatherman_execution "${_IMPORT_PREFIX}/lib/libleatherman_execution.so.2.0" )

# Import target "leatherman_ruby" for configuration "Release"
set_property(TARGET leatherman_ruby APPEND PROPERTY IMPORTED_CONFIGURATIONS RELEASE)
set_target_properties(leatherman_ruby PROPERTIES
  IMPORTED_LINK_DEPENDENT_LIBRARIES_RELEASE "leatherman_dynamic_library;leatherman_util;leatherman_execution;leatherman_locale;leatherman_logging"
  IMPORTED_LOCATION_RELEASE "${_IMPORT_PREFIX}/lib/libleatherman_ruby.so.1.0"
  IMPORTED_SONAME_RELEASE "libleatherman_ruby.so.1.0"
  )

list(APPEND _IMPORT_CHECK_TARGETS leatherman_ruby )
list(APPEND _IMPORT_CHECK_FILES_FOR_leatherman_ruby "${_IMPORT_PREFIX}/lib/libleatherman_ruby.so.1.0" )

# Commands beyond this point should not need to know the version.
set(CMAKE_IMPORT_FILE_VERSION)
